@@ -5,4 +5,4 @@ RSpec.configure do |c|
   c.filter_run_excluding :unresolved => true
 end
 
-Dir['spec/*_spec.rb'].each { |f| require f }
+Dir['./spec/*_spec.rb'].each { |f| require f }
